@@ -1,29 +1,26 @@
 #' @title Basic descriptive statistics
 #' @name descr
 #'
-#' @description This function wraps the \code{\link[psych]{describe}}-function
-#'              and prints a basic descriptive statistic, including variable labels.
+#' @description This function prints a basic descriptive statistic, including
+#'   variable labels.
 #'
 #' @param x A vector or a data frame. May also be a grouped data frame
-#'          (see 'Note' and 'Examples').
+#'    (see 'Note' and 'Examples').
 #' @param max.length Numeric, indicating the maximum length of variable labels
-#'          in the output. If variable names are longer than \code{max.length},
-#'          they will be shortened to the last whole word within the first
-#'          \code{max.length} chars.
+#'    in the output. If variable names are longer than \code{max.length},
+#'    they will be shortened to the last whole word within the first
+#'    \code{max.length} chars.
 #' @param out Character vector, indicating whether the results should be printed
-#'        to console (\code{out = "txt"}) or as HTML-table in the viewer-pane
-#'        (\code{out = "viewer"}) or browser (\code{out = "browser"}).
+#'    to console (\code{out = "txt"}) or as HTML-table in the viewer-pane
+#'    (\code{out = "viewer"}) or browser (\code{out = "browser"}).
 #'
 #' @inheritParams to_factor
 #'
-#' @return A data frame with basic descriptive statistics, derived from the
-#'         \code{\link[psych]{describe}}-function. The additional column
-#'         \code{NA.prc} informs about the percentage of missing values in
-#'         a variable.
+#' @return A data frame with basic descriptive statistics.
 #'
 #' @note \code{data} may also be a grouped data frame (see \code{\link[dplyr]{group_by}})
-#'       with up to two grouping variables. Descriptive tables are created for each
-#'       subgroup then.
+#'    with up to two grouping variables. Descriptive tables are created for each
+#'    subgroup then.
 #'
 #' @examples
 #' data(efc)
@@ -48,7 +45,6 @@
 #'
 #' @importFrom tibble as_tibble rownames_to_column
 #' @importFrom dplyr select mutate
-#' @importFrom psych describe
 #' @importFrom sjlabelled copy_labels
 #' @export
 descr <- function(x, ..., max.length = NULL, out = c("txt", "viewer", "browser")) {
@@ -108,41 +104,79 @@ descr <- function(x, ..., max.length = NULL, out = c("txt", "viewer", "browser")
 }
 
 
-#' @importFrom tibble add_column as_tibble rownames_to_column
-#' @importFrom psych describe
-#' @importFrom dplyr select mutate
+#' @importFrom dplyr select_if group_by summarise_all funs
+#' @importFrom tidyr gather
 #' @importFrom sjlabelled get_label
-#' @importFrom purrr map_dbl
+#' @importFrom stats var na.omit sd median
+#' @importFrom tibble add_column
+#' @importFrom rlang .data
 descr_helper <- function(dd, max.length) {
-  # get default variable name
-  var.name <- colnames(dd)
-  if (is.null(var.name)) var.name <- NA
 
   # check if we have a single vector, because purrr would return
   # a result for each *value*, instead one result for the complete vector
   if (!is.data.frame(dd))
-    dv <- as.data.frame(dd)
-  else
-    dv <- dd
+    dd <- as.data.frame(dd)
 
+  ff <- function(x) is.numeric(x) | is.factor(x)
+  dd <- dplyr::select_if(dd, ff)
 
-  # call psych::describe and convert to tibble, remove some unnecessary
-  # columns and and a variable label column
-  x <- tibble::as_tibble(psych::describe(dd, fast = FALSE)) %>%
-    tibble::rownames_to_column(var = "variable") %>%
-    dplyr::select(-.data$vars, -.data$mad) %>%
-    dplyr::mutate(
-      label = unname(sjlabelled::get_label(dd, def.value = var.name)),
-      NA.prc = purrr::map_dbl(dv, ~ 100 * sum(is.na(.x)) / length(.x))
-    ) %>%
-    var_rename(median = "md")
+  # get default variable name
+  var.name <- colnames(dd)
+  if (is.null(var.name)) var.name <- NA
+
+  type <- var_type(dd)
+  labels <- unname(sjlabelled::get_label(dd, def.value = var.name))
+
+  dd <- to_value(dd, keep.labels = FALSE)
+
+  x <- suppressWarnings(
+    dd %>%
+      dplyr::select_if(is.numeric) %>%
+      tidyr::gather(key = "var", value = "val") %>%
+      dplyr::group_by(.data$var) %>%
+      dplyr::summarise_all(
+        dplyr::funs(
+          n = length(stats::na.omit(.data$val)),
+          NA.prc = 100 * sum(is.na(.data$val)) / length(.data$val),
+          mean = mean(.data$val, na.rm = TRUE),
+          sd = stats::sd(.data$val, na.rm = TRUE),
+          se = sqrt(stats::var(.data$val, na.rm = TRUE) / length(stats::na.omit(.data$val))),
+          md = stats::median(.data$val, na.rm = TRUE),
+          trimmed = mean(.data$val, na.rm = TRUE, trim = .1),
+          range = sprintf(
+            "%s (%s-%s)",
+            as.character(round(diff(range(.data$val, na.rm = TRUE)), 2)),
+            as.character(round(min(.data$val, na.rm = TRUE), 2)),
+            as.character(round(max(.data$val, na.rm = TRUE), 2))
+          ),
+          skew = sjmisc.skew(.data$val)
+        ))
+    )
+
+    # summarise_all() sorts variables, so restore order
+    x <- x[match(var.name, x$var), ] %>%
+      tibble::add_column(
+        type = type,
+        label = labels,
+        .after = 1
+      )
 
   # check if labels should be truncated
   x$label <- shorten_string(x$label, max.length)
 
-  # sort columns a bit
-  x <- x[, c(1, 13, 2, 14, 3, 4, 12, 5, 6, 7, 8, 9, 10, 11)]
+  x
+}
 
-  # add type-column
-  tibble::add_column(x, type = var_type(dv), .after = 1)
+
+sjmisc.skew <- function(x) {
+  if (any(ina <- is.na(x)))
+    x <- x[!ina]
+
+  n <- length(x)
+  x <- x - mean(x)
+
+  if (n < 3)
+    return(NA)
+
+  sqrt(n) * sum(x ^ 3) / (sum(x ^ 2) ^ (3 / 2)) * sqrt(n * (n - 1)) / (n - 2)
 }
